define(
//begin v1.x content
{
	"HKD_displayName": "Δολάριο Χονγκ Κονγκ",
	"CNY_displayName": "Γουάν Κίνας",
	"JPY_displayName": "Γιεν Ιαπωνίας",
	"JPY_symbol": "JP¥",
	"USD_displayName": "Δολάριο ΗΠΑ",
	"CAD_symbol": "CA$",
	"GBP_displayName": "Λίρα Στερλίνα Βρετανίας",
	"CHF_displayName": "Φράγκο Ελβετίας",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "Ευρώ",
	"GBP_symbol": "£",
	"CAD_displayName": "Δολάριο Καναδά",
	"USD_symbol": "$",
	"EUR_symbol": "€",
	"AUD_displayName": "Δολάριο Αυστραλίας",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "A$"
}
//end v1.x content
);